Register at Bike Forums
Description: bike and bicycle discussion forums.
Keywords: bike forums, bicycle discussion forum, cycling forums

- Register
- Help
- Remember Me?

Advertise on Bikeforums.net

# Registration

## Register at Bike Forums

### Required Information

User Name:
PLEASE NOTE: Usernames must contain alphanumeric characters (letters & numbers) only — no punctuation or special characters. You will not be able to change your username. Do not create a username that you may need or want to change; for example, do not use your current location/airport code, or include any part of your real name or email address, etc.

Please enter the name by which you would like to log-in and be known on this site.

- Password:
- Confirm Password:

Please enter a password for your user account. Note that passwords are case-sensitive.

- Email Address:
- Confirm Email Address:

Please enter a valid email address for yourself.

Image Verification

### Additional Information

Time Zone:

All timestamps displayed on the forums can be automatically corrected to show the correct time for your location in the world. Simply select the appropriate time zone from the list below.

DST Correction Option:

In addition, you may set the appropriate option to allow for daylight savings time in your part of the world.

Receive Email...

- Receive Email from Administrators
- Receive Email from Other Members

From time to time, the administrators and/or other members may want to send you email notifications or messages. If you do not want to receive email from certain people then you may disable the options here

## Forum Guidelines

In order to proceed, you must agree with the following guidelines:

Forum Rules

Registration to this forum is free! We do insist that you abide by the rules and policies detailed below. If you agree to the terms, please check the 'I agree' checkbox and press the 'Complete Registration' button below. If you would like to cancel the registration, click here to return to the forums index.

Basic Guidelines

The following seven categories of online conduct are unacceptable at BikeForums and constitute a violation of our Community Standards which may result in warning, suspension or loss of membership:
Harrassment... Harassment occurs when a member insults, attacks, and denigrates another member at any time. We have zero tolerance for taking an argument about a any topic to a personal level. For instance, the use of terms such as "idiot, moron, stupid" and other derogatory terms constitutes harassment. The idea is to make this a pleasant environment to discuss cycling, not a schoolyard, or name-calling and rock-throwing festival. Repeated critical and sharply negative posts toward a forum member can also constitute harassment. This applies to all content submitted by users including posts, avatars and signatures.
Personal attacks and inflammatory behavior will not be tolerated.
Respect the forum staff. We're not here to make life harder to anyone. Any decision taken by the administrators and moderators is final and must be respected.
Disruption... Posts which intend to disrupt the topic of conversation or steer the topic away from the focus of the forum and related news. Disruption can include harassment, multiple user profiles, multiple posting of the same post and posting completely off topic messages. Please do your best when it comes to grammar, punctuation and spelling. Excessive use of "AOL'ese" and "hAx0r" talk can be very disruptive so please keep it to a minimum. Private messages are to be kept private and never posted in the forums.
Vulgarity... As a community with a diverse variety of members and readers, we ask that our members to post without using vulgarity. Vulgarity not only includes vulgar language and pictures but also sexist, racist, anti-religious, images of graphic violence, political statements and homophobic language which may offend other members. In addition, the "masking" of vulgarity by inserting * or another keystroke in place of one or more letters in a vulgar term is unacceptable in most cases. This applies to all content submitted by users including posts, PMs, avatars and signatures.
Solicitation... Refrain from using BikeForums to advertise your site, items for sale, commercial services or website. You may attach a short link to your site within your profile or signature.
Spamming... Spamming is the multiple posting of an identical or similar post on one or more of our Forums. Spam is also flooding the Internet with many copies of the same message, in an attempt to force the message on people who would not otherwise choose to receive it. Most spam is commercial advertising, often for dubious products, get-rich-quick schemes, or quasi-legal services.
Copyrighted Material... You may post links to appropriate articles but posting articles from other sources in their entirety is a violation of our Forum Guidelines. If you must repost quotes or sentences, please credit the source.
High Maintenance Clause... Any member who occupies a majority of admin or moderator time unnecessarily will be shown the door.
Any messages you post in these discussion forums will remain available to the public for as long as this discussion board is online. Once you have posted your message, it will stay online. Please post carefully and with due consideration to the content of your post. Usergroups are subject to the same guidelines as the main forums, and if these groups become a problem for the Administrators and Moderation staff, appropriate action, ranging from changes in the group founder to an outright disbanding of the offending group may be taken.
Please bear in mind that these are only guidelines; there is always a "grey area" and we understand that. Please also keep in mind that the the moderators' decision is final.

I have read, and agree to abide by the guidelines. I agree to receive BikeForum's newsletter. I can unsubscribe at any time.